@@ -20,10 +20,10 @@ class capitalDivisionAsker : public boxAsker
 		capitalDivisionAsker(QWidget *parent, KGmap *m, QWidget *w, uint count);
 
 	protected:
-		bool nextBoxAskerQuestionHook(const QString &division, int i, bool isAnswer);
-		void setAnswerHook(int userSays);
-		QString getQuestionHook() const;
-		division::askMode askMode() const { return division::eCapital; }
+		bool nextBoxAskerQuestionHook(const QString &division, int i, bool isAnswer) override;
+		void setAnswerHook(int userSays) override;
+		QString getQuestionHook() const override;
+		division::askMode askMode() const override { return division::eCapital; }
 	
 	private:
 		QString p_capital;
